@@ -1,46 +1,30 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "importimapsettingsakonadicheckjob.h"
 #include "importimapsettingsakonadipassword.h"
 #include "libsieveeditor_export.h"
 #include "sieveeditor_debug.h"
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
-#include <QStandardPaths>
 #include <QDir>
 #include <QFile>
+#include <QStandardPaths>
 
 ImportImapSettingsAkonadiCheckJob::ImportImapSettingsAkonadiCheckJob(QObject *parent)
     : AbstractImapSettingsCheckJob(parent)
 {
 }
 
-ImportImapSettingsAkonadiCheckJob::~ImportImapSettingsAkonadiCheckJob()
-{
-}
+ImportImapSettingsAkonadiCheckJob::~ImportImapSettingsAkonadiCheckJob() = default;
 
 bool ImportImapSettingsAkonadiCheckJob::resourceCanHaveSieveSupport(const QString &filename) const
 {
-    return filename.startsWith(QLatin1String("akonadi_kolab_resource"))
-           || filename.startsWith(QLatin1String("akonadi_imap_resource"));
+    return filename.startsWith(QLatin1String("akonadi_kolab_resource")) || filename.startsWith(QLatin1String("akonadi_imap_resource"));
 }
 
 void ImportImapSettingsAkonadiCheckJob::start()
@@ -51,29 +35,55 @@ void ImportImapSettingsAkonadiCheckJob::start()
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*rc"));
         for (const QString &file : fileNames) {
             if (resourceCanHaveSieveSupport(file)) {
-                if (importSettings(dir, file)) {
-                    mSettingsWereImported = true;
-                }
+                mSieveServerLst.insert(dir, file);
             }
         }
     }
-    checkNoSettingsImported();
+    loadSieveServerSettings();
 }
 
-bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory, const QString &filename)
+void ImportImapSettingsAkonadiCheckJob::slotImportNextServerSieveDone(const SieveEditorUtil::SieveServerConfig &config, const QString &filename)
 {
-    const QString filePath = directory +  QLatin1Char('/') + filename;
-    //qCDebug(SIEVEEDITOR_LOG) << "importSettings filename:" << filePath;
+    if (config.isValid()) {
+        Q_EMIT importSetting(filename, config);
+        mSettingsWereImported = true;
+    }
+    importNextServerSieve();
+}
+
+void ImportImapSettingsAkonadiCheckJob::loadSieveServerSettings()
+{
+    mSieveServerMapIterator = mSieveServerLst.constBegin();
+    if (mSieveServerMapIterator != mSieveServerLst.constEnd()) {
+        importSettings(mSieveServerMapIterator.key(), mSieveServerMapIterator.value());
+    }
+}
+
+void ImportImapSettingsAkonadiCheckJob::importNextServerSieve()
+{
+    ++mSieveServerMapIterator;
+    if (mSieveServerMapIterator != mSieveServerLst.constEnd()) {
+        importSettings(mSieveServerMapIterator.key(), mSieveServerMapIterator.value());
+    } else {
+        checkNoSettingsImported();
+    }
+}
+
+void ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory, const QString &filename)
+{
+    const QString filePath = directory + QLatin1Char('/') + filename;
+    // qCDebug(SIEVEEDITOR_LOG) << "importSettings filename:" << filePath;
     if (!QFileInfo::exists(filePath)) {
         qCWarning(SIEVEEDITOR_LOG) << "Unable to open file " << filePath;
-        return false;
+        importNextServerSieve();
+        return;
     }
     SieveEditorUtil::SieveServerConfig config;
-    bool isKolabSettings = filePath.contains(QLatin1String("/akonadi_kolab_resource"));
+    const bool isKolabSettings = filePath.contains(QLatin1String("/akonadi_kolab_resource"));
     KSharedConfigPtr resourceConfig = KSharedConfig::openConfig(filePath);
 
     KConfigGroup sieveGroup = resourceConfig->group(QStringLiteral("siever"));
-    bool hasSieveSupport = sieveGroup.readEntry(QStringLiteral("SieveSupport"), isKolabSettings ? true : false);
+    const bool hasSieveSupport = sieveGroup.readEntry(QStringLiteral("SieveSupport"), isKolabSettings ? true : false);
     if (hasSieveSupport) {
         bool reuseImapSettings = sieveGroup.readEntry(QStringLiteral("SieveReuseConfig"), true);
         KConfigGroup networkGroup = resourceConfig->group(QStringLiteral("network"));
@@ -83,10 +93,8 @@ bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
         config.sieveImapAccountSettings.setUserName(userName);
         config.sieveImapAccountSettings.setServerName(imapServerName);
         config.sieveImapAccountSettings.setPort(imapPort);
-        config.sieveImapAccountSettings.setAuthenticationType(
-            static_cast<KSieveUi::SieveImapAccountSettings::AuthenticationMode>(
-                networkGroup.readEntry(QStringLiteral("Authentication"),
-                                       static_cast<int>(KSieveUi::SieveImapAccountSettings::Plain))));
+        config.sieveImapAccountSettings.setAuthenticationType(static_cast<KSieveUi::SieveImapAccountSettings::AuthenticationMode>(
+            networkGroup.readEntry(QStringLiteral("Authentication"), static_cast<int>(KSieveUi::SieveImapAccountSettings::Plain))));
         const QString encryption = networkGroup.readEntry(QStringLiteral("Safety"));
         if (encryption == QLatin1String("SSL")) {
             config.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::SSLorTLS);
@@ -94,7 +102,7 @@ bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
             config.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
         } else if (encryption == QLatin1String("None")) {
             config.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::Unencrypted);
-        } else if (encryption.isEmpty()) { //Default value
+        } else if (encryption.isEmpty()) { // Default value
             if (isKolabSettings) {
                 config.sieveImapAccountSettings.setEncryptionMode(KSieveUi::SieveImapAccountSettings::EncryptionMode::STARTTLS);
             } else {
@@ -110,23 +118,19 @@ bool ImportImapSettingsAkonadiCheckJob::importSettings(const QString &directory,
         if (reuseImapSettings) {
             config.sieveSettings.serverName = imapServerName;
             config.sieveSettings.userName = userName;
-            config.sieveSettings.authenticationType
-                = static_cast<MailTransport::Transport::EnumAuthenticationType::type>(sieveGroup.readEntry(QStringLiteral("Authentication"),
-                                                                                                           static_cast<int>(MailTransport::Transport::EnumAuthenticationType::PLAIN)));
+            config.sieveSettings.authenticationType = static_cast<MailTransport::Transport::EnumAuthenticationType::type>(
+                sieveGroup.readEntry(QStringLiteral("Authentication"), static_cast<int>(MailTransport::Transport::EnumAuthenticationType::PLAIN)));
         } else {
             const QString sieveCustomUserName = sieveGroup.readEntry(QStringLiteral("SieveCustomUsername"));
             config.sieveSettings.userName = sieveCustomUserName;
-            config.sieveSettings.serverName = imapServerName; //FIXME
-            //TODO
+            config.sieveSettings.serverName = imapServerName; // FIXME
+            // TODO
         }
         Q_ASSERT_X(mPasswordImporter, "Missing mPasswordImporter", "You must create a mPasswordImporter");
         mPasswordImporter->importPasswords(config, filename, reuseImapSettings);
-        if (config.isValid()) {
-            Q_EMIT importSetting(filename, config);
-            return true;
-        }
+    } else {
+        importNextServerSieve();
     }
-    return false;
 }
 
 bool ImportImapSettingsAkonadiCheckJob::settingsCanBeImported() const
@@ -147,3 +151,9 @@ QString ImportImapSettingsAkonadiCheckJob::name() const
 {
     return i18n("Akonadi IMAP Settings");
 }
+
+void ImportImapSettingsAkonadiCheckJob::setImapSettingsPassword(AbstractImapSettingsPassword *passwordImporter)
+{
+    mPasswordImporter = passwordImporter;
+    connect(mPasswordImporter, &AbstractImapSettingsPassword::importPasswordDone, this, &ImportImapSettingsAkonadiCheckJob::slotImportNextServerSieveDone);
+}
