@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,9 +26,7 @@ ImportImapSettingSearchPage::ImportImapSettingSearchPage(QWidget *parent)
     connect(mFoundProgramList, &QListWidget::itemChanged, this, &ImportImapSettingSearchPage::slotItemChanged);
 }
 
-ImportImapSettingSearchPage::~ImportImapSettingSearchPage()
-{
-}
+ImportImapSettingSearchPage::~ImportImapSettingSearchPage() = default;
 
 void ImportImapSettingSearchPage::setProgramList(const QStringList &lst)
 {
