@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,7 +17,11 @@
 #include <QRegularExpression>
 #include <QUrlQuery>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <qt5keychain/keychain.h>
+#else
+#include <qt6keychain/keychain.h>
+#endif
 using namespace QKeychain;
 
 QUrl SieveEditorUtil::SieveServerConfig::url() const
